## seaborn_extensions

**==================**

**My collection of general plotting functions that I build on top of seaborn.**

* Free software: GNU General Public License v3
* Documentation: [https://seaborn-extensions.readthedocs.io](https://seaborn-extensions.readthedocs.io)

**Features**

* **swarmboxenplot:** Overlayed swarm- and boxen-plots with significance bars between groups.
* **clustermap:** The great clustermap but with easy annotation of rows and columns for numeric and categorical factors.
* **volcano_plot:** A volcano plot with great defaults.
* **rankplot:** A simple rank vs value plot, also known as a waterfall plot.

**Installation**

To install seaborn_extensions, simply use pip:

```bash
pip install seaborn_extensions
```

**Credits**

This package was created with Cookiecutter and the `audreyr/cookiecutter-pypackage` project template.

* Cookiecutter: [https://github.com/audreyr/cookiecutter](https://github.com/audreyr/cookiecutter)
* `audreyr/cookiecutter-pypackage`: [https://github.com/audreyr/cookiecutter-pypackage](https://github.com/audreyr/cookiecutter-pypackage)
